@@ -51,7 +51,7 @@ GtkTreeIter iter;
 void gnome_internet_radio_locator_helper_run(gchar *url, gchar *name, GNOMEInternetRadioLocatorStreamType type, GNOMEInternetRadioLocatorHelperType helper)
 {
 	GError *err = NULL;
-	GDateTime *mtime;
+	GTimeVal mtime;
 	/* const char *mime_info = NULL; */
 	/* GnomeVFSMimeApplication *app; */
 	char *app = NULL, *command = NULL, *msg = NULL;
@@ -72,7 +72,7 @@ void gnome_internet_radio_locator_helper_run(gchar *url, gchar *name, GNOMEInter
 
 	/* mime_info = gnome_vfs_get_mime_type(url); */
 
-	mtime = g_get_real_time();
+	g_get_current_time(&mtime);
 
 	/* app = (gchar *)gnome_vfs_mime_get_default_application (mime_info); */
 
